#!/usr/bin/python3
# -*- coding: UTF-8 -*-
# ver 0.0.2
# Author - Alexey Rodionov, Artem Radevich, RED SOFT, 2023

import os
import gi
from subprocess import Popen, PIPE

gi.require_version('Gtk', '3.0')
from gi.repository import Gtk, Gio

BASE_KEY = "org.mate.panel"
LIKE_GNOME_LAYOUT = "oldschool"
LIKE_WINDOWS_LAYOUT = "ventanaXP"
LIKE_WIN10_LAYOUT = "ventana7"
LIKE_MACOS_LAYOUT = "vespanamaca"

UNKNOWN_LAYOUT = "unknown"

# ---
class Handler:
    def on_main_window_destroy(self, *args):
        Gtk.main_quit()

    def on_radiobutton_toggled(self, *args):
        global NewLayout
        global PreLayout

        if like_gnome.get_active():
            NewLayout = LIKE_GNOME_LAYOUT
        elif like_windows.get_active():
            NewLayout = LIKE_WINDOWS_LAYOUT
        elif like_win10.get_active():
            NewLayout = LIKE_WIN10_LAYOUT
        elif like_macos.get_active():
            NewLayout = LIKE_MACOS_LAYOUT

        if NewLayout == PreLayout:
            apply_button.set_sensitive(0)
        else:
            apply_button.set_sensitive(1)

    def on_applybutton_clicked(self, *args):
        global NewLayout
        global PreLayout
        # Текст для добавления файла в автостарт
        plank_str = """[Desktop Entry]
Type=Application
Exec=plank
Hidden=false
Name[ru_RU]=plank
Name=plank
Comment[ru_RU]=Dock
Comment=Dock
X-MATE-Autostart-Delay=0
"""
        # Путь к файлу автостарта
        folder_path = os.path.expanduser("~/.config/autostart")
        if not os.path.exists(os.path.expanduser(folder_path)):
            os.makedirs(os.path.expanduser(folder_path))
        correct_path = os.path.expanduser("~/.config/autostart/plank.desktop")
        # Пишем имя раскладки в dconf и перезапускаем mate-panel
        if like_gnome.get_active():
            settings.set_string("default-layout", LIKE_GNOME_LAYOUT)
            NewLayout = LIKE_GNOME_LAYOUT
            process = Popen(['killall', 'plank'], stdout=PIPE, stderr=PIPE)
            stdout, stderr = process.communicate()
            if os.path.exists(correct_path):
                os.remove(correct_path)
            else:
                print("The file does not exist")
        if like_windows.get_active():
            settings.set_string("default-layout", LIKE_WINDOWS_LAYOUT)
            NewLayout = LIKE_WINDOWS_LAYOUT
            process = Popen(['killall', 'plank'], stdout=PIPE, stderr=PIPE)
            stdout, stderr = process.communicate()
            if os.path.exists(correct_path):
                os.remove(correct_path)
            else:
                print("The file does not exist")
        if like_win10.get_active():
            settings.set_string("default-layout", LIKE_WIN10_LAYOUT)
            NewLayout = LIKE_WIN10_LAYOUT
            process = Popen(['killall', 'plank'], stdout=PIPE, stderr=PIPE)
            stdout, stderr = process.communicate()
            if os.path.exists(correct_path):
                os.remove(correct_path)
            else:
                print("The file does not exist")
        if like_macos.get_active():
            settings.set_string("default-layout", LIKE_MACOS_LAYOUT)
            NewLayout = LIKE_MACOS_LAYOUT
            os.system('plank &')
            with open(correct_path, "w") as f:
                f.write(plank_str)
        os.system('mate-panel --reset')


        PreLayout = NewLayout
        apply_button.set_sensitive(0)

#
# --- Основной блок ---
#
if __name__ == '__main__':
    # Строим интерфейс окна
    builder = Gtk.Builder()
    builder.add_from_file("/usr/share/mate-layout-chooser/mate-layout-chooser.ui")
#    builder.add_from_file("mate-layout-chooser.ui")
    builder.connect_signals(Handler())
    window = builder.get_object("main_window")

    # Подключаемся к dconf
    settings = Gio.Settings.new(BASE_KEY)
    NewLayout = settings.get_string("default-layout")
    PreLayout = NewLayout

    # Устанавливаем активную компоновку
    like_gnome = builder.get_object("LikeGNOME_RadioButton")
    like_windows = builder.get_object("LikeWin_RadioButton")
    like_win10 = builder.get_object("LikeWin10_RadioButton")
    like_macos = builder.get_object("LikeMacos_RadioButton")
    apply_button = builder.get_object("apply_button")

    if NewLayout == LIKE_WINDOWS_LAYOUT:
        like_windows.set_active(1)
    else:
        if NewLayout == LIKE_GNOME_LAYOUT:
            like_gnome.set_active(1)
        else:
            # Если текущая раскладка не относится к типовым для РО, то текущая
            # устанавливается как неизвестная (unknown), а новая - в стиле
            # Windows (ventana)
            NewLayout = LIKE_WINDOWS_LAYOUT
            PreLayout = UNKNOWN_LAYOUT
            like_windows.set_active(1)

    # Если действующая раскладка неизвестна, то кнопка "Применить" делается активной,
    # в противном слуаче - кнопка неактивна, пока не изменится выбор компоновки
    SESS = os.getenv('DESKTOP_SESSION')
    if SESS == 'mate':
      like_gnome.set_sensitive(1)
      like_windows.set_sensitive(1)
      like_win10.set_sensitive(1)
      like_macos.set_sensitive(1)
    else:
      like_gnome.set_sensitive(0)
      like_windows.set_sensitive(0)
      like_win10.set_sensitive(0)
      like_macos.set_sensitive(0)

    if PreLayout == UNKNOWN_LAYOUT:
        apply_button.set_sensitive(1)
    else:
        apply_button.set_sensitive(0)

    window.show_all()
    window.set_title("Выбор компоновки Рабочего Стола")
    Gtk.main()
